// Parent class for all addressable LED strips.
// Partially based on work by and (c) 2011 Jelmer Tiete
// whose library is ported from the Arduino implementation of Adafruit Industries
// found at: http://github.com/adafruit/LPD8806
// and their strips: http://www.adafruit.com/products/306
// Released under the MIT License: http://mbed.org/license/mit

// This is a pure virtual parent class for all LED strips, so that different types
// of strip may be used in a single array or container.

#include "mbed.h"
#ifndef LEDSTRIP_H
#define LEDSTRIP_H
 
class LedStrip {
 public:
  virtual void begin(void)=0;
  virtual void show(void)=0;
  virtual void blank(void)=0;
  virtual void setPixelColor(uint16_t n, uint8_t r, uint8_t g, uint8_t b)=0;
  virtual void setPackedPixels(uint8_t * buffer, uint32_t n)=0;
  virtual void setPixelB(uint16_t n, uint8_t b)=0;
  virtual void setPixelG(uint16_t n, uint8_t g)=0;
  virtual void setPixelR(uint16_t n, uint8_t r)=0;
  virtual void setPixelColor(uint16_t n, uint32_t c)=0;
  virtual uint16_t numPixels(void)=0;
  virtual uint32_t Color(uint8_t, uint8_t, uint8_t)=0;
  virtual uint32_t total_luminance(void)=0;
};
#endif